-- This example is like basic/outlet_settings.lua but pcall is used to catch
-- failure (exceptions)

require "Pdu"

-- get pdu and outlet 3 object
local pdu = pdumodel.Pdu:getDefault()
local out3 = pdu:getOutlets()[3]

-- test if outlet 3 exists
assert(out3)

-- wrongSettings is just a string. Lua script crashes if you try to call
--  setSettings(wrongSettings)
wrongSettings = "sadf"

-- PCALL EXAMPLE 1
print("Example 1")
-- 'status = out3:setSettings()' - the code to execute
-- 'funciont() ... end'          - anonymous function
-- 'err, errMsg = pcall( ... )'  - pcall statement
-- http://www.lua.org/manual/5.3/manual.html#pdf-pcall
--                 function ()  CODE TO EXECUTE  end
local status = nil
err, errMsg = pcall(function() status = out3:setSettings(wrongSettings) end)
if err == false then 
  print("error catched: " ..  errMsg) 
else
  print "no failure catched" 
end

-- status is still nil
assert(status == nil)

-- PCALL EXAMPLE 2
print("Example 2")
-- another syntax to call setSetting() in a pcall statement
--                 (function        , object, argument     )
err, errMsg = pcall(out3.setSettings, out3  , wrongSettings)
if err == false then
  print("error catched: " ..  errMsg)
else
  print "no failure catched"
end

-- PCALL EXAMPLE FAIL
print("Example fails")
-- Here executes the return value in protected mode, but the failure - that is going
-- to be happend - will not be execute in the protected mode! => script crashes here!!!
err, errMsg = pcall(out3:setSettings(wrong))
if err == false then
  print("error catched: " ..  errMsg)
else
  print "no failure catched"
end
