-- This script enables or disables event rules.
-- To specify the rule to enable or disable use script arguments. The key is
-- the rule name and the value can be 'enableRule' or 'disableRule' to enable
-- or disable the rule.

-- This script can be used to schedule off-time/on-time of rules.
--   Put the script on your pdu. Create a new action and choose 'Start/Stop Lua
--   Script'. Set Operation to 'Start Script' and select the uploaded script at
--   the field 'Script'. Now add some 'Script Arguments'. The key is the rule 
--   name and the value can be 'enableRule' to enable the rule or 'disableRule'
--   to disable the rule. After the action is created add a 'Scheduled Action'
--   and set the new action as 'Selected Action'.

require "EventEngine"

-- keywords to identify a rule name to handle
local enableKeyword  = "enablerule"      -- lower case!
local disableKeyword = "disablerule"     -- lower case!

local engine = event.Engine:getDefault()
local rules  = engine:listRules()

-- check if onOffKeyword does match
function onOffKeywordIsValid(onOff)
  if onOff == enableKeyword or onOff == disableKeyword then
    return true
  else
    return false
  end
end

-- status to string
function statusToString(status)
  if status == 0 then
    return "OK"
  elseif status == 1 then
    return "RULE IS UNKNOWN"
  end
  return "STATUS NOT KNOWN (" .. status ..")"
end

-- function to enable or disable a rule
function switchRule(rule, onOff)
  -- enable rule
  if onOff == enableKeyword then
    local status = engine:enableRule(rule.id)
    print("ENABLE rule '" .. rule.name .. "' returns: " .. statusToString(status))
  
  -- disable rule
  elseif onOff == disableKeyword then
    local status = engine:disableRule(rule.id)
    print("DISABLE rule '" .. rule.name .. "' returns: " .. statusToString(status))
  end
end

-- function to iterate through all event rules
function getRuleWithName(name)
  for index,rule in ipairs(rules) do
    if name == rule.name then
      return rule
    end
  end
  -- return nil if name does not match to any rule
  return nil
end

-- main program
print(os.date("started rule switcher - %c"))

for name,onOff in pairs(ARGS) do
  onOff = string.lower(onOff) -- to lower case

  if onOffKeywordIsValid(onOff) == true then
    local rule = getRuleWithName(name)
    if rule ~= nil then
      switchRule(rule, onOff)
    else
      print("no rule with name: " .. name)
    end
  end
end
