-- Print some pdu information.
-- Iterate through all outlets and print information.
-- See how Lua tables are used as idl object, idl structs and idl vectors.

require "Pdu"

-- new pdu idl object is a Lua table. To call a pdu function use ':'
local pdu = pdumodel.Pdu:getDefault()

-- get metadata information from pdu object
local metadata = pdu:getMetaData()
-- print metadata
-- 'metadata' has an idl type of struct and is mapped to a Lua table. The Lua
-- table is used as a dictionary/map. The key is attribute name of the idl struct.
-- To print out all attributes use the buildin function 'printTable'.
print("-- pdu metadata")
printTable(metadata)  -- print the table metadata 
print()               -- empty line

-- get and print nameplate information
-- 'nameplate' has an idl type of struct too. Instead of printTable we are accessing
-- directly some nameplate information through its attributes.
local nameplate = pdu:getNameplate()
print("-- pdu nameplate")
print("manufacturer: " .. nameplate["manufacturer"])
print("model: " .. nameplate["model"])

-- rating a nasted struct
local rating = nameplate["rating"]
print("power rating: " .. rating["power"])
print()

-- iterate through all outlets and print the state and settings of the outlet
print("-- pdu outlet states and settings")
local outlets = pdu:getOutlets()
-- 'outlets' has an idl type of vector and is mapped to a Lua indexed table with
-- integers. The index starts at '1'.
for i = 1,#outlets do
  -- get the outlet at position i
  local outlet = outlets[i]
  -- get the outlet state and settings
  local state = outlet:getState()
  local settings = outlet:getSettings()

  -- print information
  print()
  print("index", i)
  print("--")
  printTable(state)
  print("--")
  printTable(settings)
end

print()
