-- Counts the power state form all outlets
-- Counts the led state from all outlets

require "Pdu"

-- get new pdu object and the outlets vector
local pdu = pdumodel.Pdu:getDefault()
local outlets = pdu:getOutlets()

-- PowerState is an idl enumeration type. We define here 'ON' with the value offCounter
-- 'pdumodel.Outlet.PowerState.PS_ON' and OFF as 'pdumodel.Outlet.PowerState.PS_OFF'.
local ON  = pdumodel.Outlet.PowerState.PS_ON
local OFF = pdumodel.Outlet.PowerState.PS_OFF

local onCounter = 0
local offCounter = 0

-- iterate through all outlets
for i = 1,#outlets do
  -- get the powerstate enumeration
  local state = outlets[i]:getState().powerState
  -- count on/off states
  if state == ON then
    onCounter = onCounter + 1
  elseif state == OFF then
    offCounter = offCounter + 1
  -- if the state is not on or off - should never happen
  else
    print("something does not match!")
  end
end

print("-- powerstate counts")
print("ON  " .. onCounter)
print("OFF " .. offCounter)
print()

-- count led state
local red = 0
local green = 0
local blinking = 0

-- iterate through all outlets
-- to ge access to some attributes 'dot notation' is used at this example
for i = 1,#outlets do
  -- combine some function call and attribute access
  local led = outlets[i]:getState().ledState
  -- long form:
  --   local outlet = outlets[i]
  --   local state  = outlet:getState()
  --   local led    = state.ledState
  if led.red      == true then red      = red      + 1 end
  if led.green    == true then green    = green    + 1 end
  if led.blinking == true then blinking = blinking + 1 end
end

print("-- led state counts")
print("red      " .. red)
print("green    " .. green)
print("blinking " .. blinking)
print()




